# Changelog

## 0.6.0 (2025-10-29)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/Alchemyst-ai/alchemyst-sdk-python/compare/v0.5.0...v0.6.0)

### Features

* **api:** manual updates ([2512789](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/2512789d20bdc320da062a5b752fdebd070fbfbb))
* **api:** manual updates ([cc4d4bd](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/cc4d4bd22e25e7f468743c8785a18f36bed2c50f))

## 0.5.0 (2025-10-29)

Full Changelog: [v0.0.1...v0.5.0](https://github.com/Alchemyst-ai/alchemyst-sdk-python/compare/v0.0.1...v0.5.0)

### Features

* **api:** api update ([8b6419b](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/8b6419b8d3645059c5231c4e14dd1fe46b6dd3d8))
* **api:** api update ([1be64d9](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/1be64d9cd19dc3df6d72ebb5b2496779e9b76424))
* **api:** api update ([2561f6c](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/2561f6c5d35bfa474858bab7ee03999c765bc7d6))
* **api:** manual updates ([fb63c26](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/fb63c269c64dea5e2881d557c81581056f21da05))
* **api:** manual updates ([d230e11](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/d230e11ea56f28969fc8b6a2c2e3f80890430b34))
* **api:** manual updates ([cf37f37](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/cf37f371698f25907a245a5db5dfd2663e1e4451))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([5ddd383](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/5ddd3838203c871a97ab101d0fa71755a3b835ef))
* do not install brew dependencies in ./scripts/bootstrap by default ([076ff5b](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/076ff5bb3bd43bd7c998a64fc5e7395eaaabdb27))
* **internal:** detect missing future annotations with ruff ([fac1c37](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/fac1c371e564ca90bc31cef5335c8285ef1ab92a))
* sync repo ([62de6e7](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/62de6e77fe0e2ea96813fec36c0e3f7eaa30ab9c))
* update SDK settings ([601825a](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/601825a483ca56ead67e7bc952ede6eb595e66f1))
* update SDK settings ([8369476](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/8369476293e115785102255d3cf1d702daf3140c))
* update SDK settings ([07f1747](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/07f1747979ce926f286592beca52748afdd79a11))
* update SDK settings ([be467f2](https://github.com/Alchemyst-ai/alchemyst-sdk-python/commit/be467f232ee161643d1a9ad804161598900d56ff))
